==> ATutor-1.6.tar.gz: ATutor/documentation/general/file_storage.php <==
<?php require('../common/body_header.inc.php'); $lm = '$LastChangedDate: 2006-06-29 11:25:07 -0400 (Thu, 29 Jun 2006) $'; ?>

<h2>File Storage</h2>

<p>Students, assistants, and instructors can access a personal file management tool using the <em>File Storage</em> area, if enabled for a course. Workspaces can be selected for storing files,  their presence depending on one's access rights:
	<ul>
		<li><em>Course Files</em> - The default workspace. Managed by the instructor, or assistants with file storage privileges, course resource files are made available for download by course members.</li>
		<li><em>My Files</em> - Private files only the user can access and manage.</li>
		<li><em>Groups</em> - Shared files managed by group members, and accessible to instructors and assistants with group privileges.</li>
		<li><em>Assignments</em> - Students can submit assignments to these workspaces, and instructors or assistants with assignment privileges can manage submissions.</li>

	</ul>

To move between workspaces, select them from the dropdown menu and use the <code>    Go!            </code>  button. To view a file in the File Storage area, download and open it locally on your own computer.
</p>
<h3>Create Folders and Adding Files</h3>
<p>To organize files, folders can be created using the <em>Create Folder</em> feature at the top right of the file area. To upload a new file, with an optional description of its contents, use the <em>New File</em> feature at the top left. The file will be uploaded to the currently opened directory.</p>

<h3>Managing Files</h3>
<p>It is also possible to <code>Download</code> files to your hard drive, <code>Hand In</code> a file for an assignment, <code>Edit</code> file details and rename folders,  <code>Move</code> files around within a workspace, as well as <code>Delete</code> files and folders. Depending on the type of workspace, the buttons that appear will vary.</p>

<h3>File Revisions</h3>

<p>If enabled, file revisions can be kept, so a history of the document or file is available. Uploading a file of the same name as one that exists, will create a second version of the file, and so on. With each revision comments can be added, to summarize the changes from authors, and to perhaps collect feedback from reviewers.</p>



<?php require('../common/body_footer.inc.php'); ?>

==> ATutor-1.6.2.tar.gz: ATutor/documentation/general/file_storage.php <==
<?php require('../common/body_header.inc.php'); $lm = '$LastChangedDate: 2008-06-13 09:48:16 -0400 (Fri, 13 Jun 2008) $'; ?>

<h2>File Storage</h2>

<p>Students, assistants, and instructors can access a personal file management tool using the <em>File Storage</em> area, if enabled for a course. Workspaces can be selected for storing files,  their presence depending on one's access rights:
	<ul>
		<li><em>Course Files</em> - The default workspace. Managed by the instructor, or assistants with file storage privileges, course resource files are made available for download by course members.</li>
		<li><em>My Files</em> - Private files only the user can access and manage.</li>
		<li><em>Groups</em> - Shared files managed by group members, and accessible to instructors and assistants with group privileges.</li>
		<li><em>Assignments</em> - Students can submit assignments from these workspaces, and instructors or assistants with assignment privileges can manage submissions from the File Storage utiilty. To submit an assignment, upload a file to <em>MyFiles</em>, or to a group workspace, then select the file you wish to hand in and press  the <em>Handin</em> button to view a list is assignments. Choose the assignment for which you are hinding in the file, then press <em>Submit</em></li>

	</ul>

To move between workspaces, select them from the dropdown menu and use the <code>    Go!            </code>  button. To view a file in the File Storage area, download and open it locally on your own computer.
</p>
<h3>Create Folders and Adding Files</h3>
<p>To organize files, folders can be created using the <em>Create Folder</em> feature at the top right of the file area. To upload a new file, with an optional description of its contents, use the <em>New File</em> feature at the top left. The file will be uploaded to the currently opened directory.</p>

<h3>Managing Files</h3>
<p>It is also possible to <code>Download</code> files to your hard drive, <code>Hand In</code> a file for an assignment, <code>Edit</code> file details and rename folders,  <code>Move</code> files around within a workspace, as well as <code>Delete</code> files and folders. Depending on the type of workspace, the buttons that appear will vary.</p>

<h3>File Revisions</h3>

<p>If enabled, file revisions can be kept, so a history of the document or file is available. Uploading a file of the same name as one that exists, will create a second version of the file, and so on. With each revision comments can be added, to summarize the changes from authors, and to perhaps collect feedback from reviewers.</p>



<?php require('../common/body_footer.inc.php'); ?>
